
History
=======

v0.1.1 / 2017-04-24
-------------------

  * fix(core): handle not present __init__ member in classes. feat(examples): add mocking example
  * fix(docs): type in about section
  * fix(setup.py): package description

v0.1.0 (2017-04-23)
-------------------

* First version (beta).
